| /freebsd/contrib/llvm-project/clang/include/clang/Basic/ |
| H A D | BuiltinsAMDGPU.def | 166 …BUILTIN(__builtin_amdgcn_raw_ptr_buffer_load_lds, "vQbv*3IUiiiIiIi", "t", "vmem-to-lds-load-insts") 201 TARGET_BUILTIN(__builtin_amdgcn_s_dcache_inv_vol, "v", "n", "ci-insts") 202 TARGET_BUILTIN(__builtin_amdgcn_buffer_wbinvl1_vol, "v", "n", "ci-insts") 203 TARGET_BUILTIN(__builtin_amdgcn_ds_gws_sema_release_all, "vUi", "n", "ci-insts") 218 TARGET_BUILTIN(__builtin_amdgcn_div_fixuph, "hhhh", "nc", "16-bit-insts") 219 TARGET_BUILTIN(__builtin_amdgcn_rcph, "hh", "nc", "16-bit-insts") 220 TARGET_BUILTIN(__builtin_amdgcn_sqrth, "hh", "nc", "16-bit-insts") 221 TARGET_BUILTIN(__builtin_amdgcn_rsqh, "hh", "nc", "16-bit-insts") 222 TARGET_BUILTIN(__builtin_amdgcn_sinh, "hh", "nc", "16-bit-insts") 223 TARGET_BUILTIN(__builtin_amdgcn_cosh, "hh", "nc", "16-bit-insts") [all …]
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/AMDGPU/ |
| H A D | AMDGPU.td | 68 def FeatureFlatGlobalInsts : SubtargetFeature<"flat-global-insts", 74 def FeatureFlatScratchInsts : SubtargetFeature<"flat-scratch-insts", 80 def FeatureScalarFlatScratchInsts : SubtargetFeature<"scalar-flat-scratch-insts", 92 def FeatureAddNoCarryInsts : SubtargetFeature<"add-no-carry-insts", 134 def FeatureMadMixInsts : SubtargetFeature<"mad-mix-insts", 140 def FeatureFmaMixInsts : SubtargetFeature<"fma-mix-insts", 146 def FeatureIEEEMinimumMaximumInsts : SubtargetFeature<"ieee-minimum-maximum-insts", 368 def FeatureCIInsts : SubtargetFeature<"ci-insts", 374 def FeatureGFX8Insts : SubtargetFeature<"gfx8-insts", 380 def FeatureGFX9Insts : SubtargetFeature<"gfx9-insts", [all …]
|
| H A D | VOPInstructions.td | 36 // First 13 insts from VOPDY are also VOPDX. DOT2ACC_F32_BF16 is omitted
|
| H A D | VOP3PInstructions.td | 29 // Used for FMA_MIX* and MAD_MIX* insts
|
| H A D | SOPInstructions.td | 2798 //relaxation for insts with no operands not implemented
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/Hexagon/MCTargetDesc/ |
| H A D | HexagonShuffler.h | 214 packet_range insts(HexagonPacket &P) { in cend() 217 const_packet_range insts(HexagonPacket const &P) const { in insts() 220 packet_range insts() { return make_range(begin(), end()); } in insts() 221 const_packet_range insts() const { return make_range(cbegin(), cend()); } in insts() function 226 return llvm::any_of(insts(), [&](HexagonInstr const &I) { in HasInstWith() 215 packet_range insts(HexagonPacket &P) { insts() function 218 const_packet_range insts(HexagonPacket const &P) const { insts() function 222 const_packet_range insts() const { return make_range(cbegin(), cend()); } insts() function
|
| H A D | HexagonShuffler.cpp | 197 for (HexagonInstr &ISJ : insts()) { in restrictSlot1AOK() 229 for (HexagonInstr &ISJ : insts()) { in restrictNoSlot1Store() 311 for (HexagonInstr &ISJ : insts()) { in permitNonSlot() 408 llvm::none_of(insts(), [&](HexagonInstr const &I) { in restrictStoreLoadOrder() 587 const bool HasOnlySlot3 = llvm::any_of(insts(), [&](HexagonInstr const &I) { in restrictPreferSlot3() 633 llvm::all_of(insts(PacketResult), [&AuctionCore](HexagonInstr const &I) { in tryAuction() 640 for (HexagonInstr const &ISJ : insts(PacketResult)) in tryAuction() 689 for (HexagonInstr const &ISJ : insts()) { in shuffle() 715 for (HexagonInstr const &I : insts()) { in reportResourceUsage()
|
| /freebsd/sys/dev/qat/qat_common/ |
| H A D | qat_hal.c | 1457 u64 insts, savuword; in qat_hal_rd_rel_reg() local 1466 insts = 0xA070000000ull | (reg_addr & 0x3ff); in qat_hal_rd_rel_reg() 1469 insts = (uint64_t)0xA030000000ull | ((reg_addr & 0x3ff) << 10); in qat_hal_rd_rel_reg() 1490 insts = qat_hal_set_uword_ecc(insts); in qat_hal_rd_rel_reg() 1491 uwrd_lo = (unsigned int)(insts & 0xffffffff); in qat_hal_rd_rel_reg() 1492 uwrd_hi = (unsigned int)(insts >> 0x20); in qat_hal_rd_rel_reg() 1530 uint64_t insts[] = { 0x0F440000000ull, in qat_hal_wr_rel_reg() local 1534 const int num_inst = ARRAY_SIZE(insts), code_off = 1; in qat_hal_wr_rel_reg() 1551 insts[imm_w1] = insts[imm_w1] | ((data16hi >> 8) << 20) | in qat_hal_wr_rel_reg() 1553 insts[imm_w0] = insts[imm_w0] | ((data16lo >> 8) << 20) | in qat_hal_wr_rel_reg() [all …]
|
| /freebsd/contrib/elftoolchain/libdwarf/ |
| H A D | libdwarf_frame.c | 550 uint8_t *insts, Dwarf_Unsigned len, Dwarf_Unsigned caf, Dwarf_Signed daf, in _dwarf_frame_run_inst() argument 585 p = insts; in _dwarf_frame_run_inst() 917 _dwarf_frame_convert_inst(Dwarf_Debug dbg, uint8_t addr_size, uint8_t *insts, in _dwarf_frame_convert_inst() argument 990 p = insts; in _dwarf_frame_convert_inst() 995 SET_INSTR_OFFSET(p - insts); in _dwarf_frame_convert_inst() 1120 _dwarf_frame_get_fop(Dwarf_Debug dbg, uint8_t addr_size, uint8_t *insts, in _dwarf_frame_get_fop() argument 1128 ret = _dwarf_frame_convert_inst(dbg, addr_size, insts, len, &count, in _dwarf_frame_get_fop() 1138 ret = _dwarf_frame_convert_inst(dbg, addr_size, insts, len, &count, in _dwarf_frame_get_fop()
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/SandboxIR/ |
| H A D | Region.h | 163 iterator_range<iterator> insts() { return make_range(begin(), end()); } in insts() function
|
| /freebsd/contrib/llvm-project/llvm/lib/Passes/ |
| H A D | PassRegistry.def | 685 "switch-to-lookup;no-keep-loops;keep-loops;no-hoist-common-insts;" 686 "hoist-common-insts;no-hoist-loads-stores-with-cond-faulting;" 687 "hoist-loads-stores-with-cond-faulting;no-sink-common-insts;" 688 "sink-common-insts;no-speculate-unpredictables;speculate-unpredictables;"
|
| /freebsd/lib/libpmc/pmu-events/ |
| H A D | README | 55 .desc = "1 or more ppc insts finished,",
|
| /freebsd/contrib/llvm-project/llvm/utils/TableGen/ |
| H A D | GlobalISelCombinerMatchTableEmitter.cpp | |
| H A D | GlobalISelCombinerEmitter.cpp | 1664 for (const CodeGenInstruction *CGI : AOP.insts()) { in emitMatchPattern()
|
| /freebsd/contrib/llvm-project/llvm/utils/TableGen/Common/GlobalISel/ |
| H A D | Patterns.h | 185 const auto &insts() const { return Insts; } in insts() function
|
| /freebsd/contrib/llvm-project/llvm/lib/AsmParser/ |
| H A D | LLLexer.cpp | 798 KEYWORD(insts); in LexIdentifier()
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/IR/ |
| H A D | Attributes.td | 204 /// Disable implicit floating point insts.
|
| /freebsd/contrib/elftoolchain/readelf/ |
| H A D | readelf.c | 307 uint8_t *insts, Dwarf_Unsigned len, Dwarf_Unsigned caf, Dwarf_Signed daf, 6045 dump_dwarf_frame_inst(struct readelf *re, Dwarf_Cie cie, uint8_t *insts, in dump_dwarf_frame_inst() argument 6057 if (dwarf_expand_frame_instructions(cie, insts, len, &oplist, in dump_dwarf_frame_inst()
|
| /freebsd/contrib/llvm-project/lldb/source/Core/ |
| H A D | IOHandlerCursesGUI.cpp | 7116 InstructionList &insts = m_disassembly_sp->GetInstructionList(); in WindowDelegateDraw() local 7123 ? insts.GetIndexOfInstructionAtAddress(pc_address) in WindowDelegateDraw() 7141 Instruction *inst = insts.GetInstructionAtIndex(inst_idx).get(); in WindowDelegateDraw()
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/M68k/ |
| H A D | M68kInstrArithmetic.td | 896 // be used with data registers, here by adding complexity to a simple ADD32ri insts
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/ARM/ |
| H A D | ARMInstrInfo.td | 5971 // These are pseudo-instructions and are lowered to individual MC-insts, so
|
| H A D | ARMInstrNEON.td | 6336 // Even without these pseudo-insts we would probably end up with the correct
|